spannertools.destroy_spanners_attached_to_components_in_expr
============================================================

.. autofunction:: abjad.tools.spannertools.destroy_spanners_attached_to_components_in_expr.destroy_spanners_attached_to_components_in_expr
   :noindex:
